OiRA

Help

1. Προετοιμασία
2. Συμμετοχή των εργαζομένων
3. Αναγνώριση + Αξιολόγηση
4. Σχέδιο Δράσης
5. Έκθεση
6. Παρούσα Κατάσταση 37%

# Παρούσα κατάσταση της μελέτης Εκτίμησης Κινδύνου Commercial guarding, Leicester

## Γενικές πληροφορίες

Εργαλείο που χρησιμοποιήθηκε ως βάση

  Commercial guarding, Leicester

ημερομηνία έναρξης

  5 August 2017 by angela.baumeister@company.com

αποθηκεύτηκε

  7 June 2018 by hans.mittelmaier@company.com

## Ερωτήσεις που απαντήθηκαν ανά ενότητα

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 Ασφαλής κατάσταση
  - 3
  - 2 Προσοχή κίνδυνος!
  - 2 Κίνδυνος σε εκκρεμότητα
  - 2 Υπό εξέταση κίνδυνος

  #### Κίνδυνοι υψηλής επικινδυνότητας

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 Υπό εξέταση κίνδυνος

  1

  1 Προσοχή κίνδυνος!

  1 Κίνδυνος σε εκκρεμότητα

  - 7 Υπό εξέταση κίνδυνος
  - 1
  - 1 Προσοχή κίνδυνος!
  - 1 Κίνδυνος σε εκκρεμότητα

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More